//  Copyright PrimeObjects Software Inc. and other contributors <https://www.primeobjects.com/>
// 
//  This source code is licensed under the MIT license.
//  The detail information can be found in the LICENSE file in the root directory of this source tree.
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React, { Fragment, useEffect, useState } from 'react';
import { isInteger, isNumber, isArray, cloneDeep } from 'lodash';
import SVG from './svg';
import { isNonEmptyString, COLORS, stringToColor, getRecordDisplay, isObject } from 'primeobjects-helper-util';
import { Menu, Transition } from '@headlessui/react';
import { map } from 'lodash';
var styles = {
    countWrapper: { position: 'absolute', top: -5, right: -5, borderRadius: 9, backgroundColor: COLORS.RED['800'], justifyContent: 'space-around' },
    count: { fontSize: 8, color: COLORS.WHITE, alignSelf: 'center' }
};
export var Avatar = function (props) {
    var countWrapperStyle = props.countWrapperStyle, countStyle = props.countStyle, hide = props.hide, count = props.count, menu = props.menu, wrapperClassName = props.wrapperClassName, wrapperStyle = props.wrapperStyle, nameStyle = props.nameStyle, svgStyle = props.svgStyle, nameToColor = props.nameToColor, notUser = props.notUser, imgStyle = props.imgStyle;
    var _a = useState({}), data = _a[0], setData = _a[1];
    var backgroundColor = isNonEmptyString(props.backgroundColor) ? props.backgroundColor : COLORS.WHITE;
    var borderColor = isNonEmptyString(props.borderColor) ? props.borderColor : COLORS.BLACK;
    var color = isNonEmptyString(props.color) ? props.color : borderColor;
    var display = getRecordDisplay(data);
    if (nameToColor) {
        backgroundColor = stringToColor(display);
        borderColor = backgroundColor;
        color = COLORS.WHITE;
    }
    useEffect(function () {
        setData(isObject(props.data) ? cloneDeep(props.data) : {});
    }, [props.data]);
    var size = isInteger(props.size) ? props.size : 38;
    var firstName = data.firstName, lastName = data.lastName;
    if (!isNonEmptyString(firstName) && !isNonEmptyString(firstName) && !notUser) {
        firstName = display.split(' ')[0];
        if (display.split(' ').length > 1)
            lastName = display.split(' ')[1];
    }
    //if (_track) console.log({ data })
    var renderName = function () {
        if (isNonEmptyString(data.avatar))
            return null;
        return (isNonEmptyString(firstName) || isNonEmptyString(firstName)) ?
            React.createElement("div", { className: "flex flex-row items-center rounded-full border", style: __assign({ minWidth: size, minHeight: size, borderColor: borderColor, backgroundColor: backgroundColor }, nameStyle) },
                React.createElement("div", { className: "flex flex-row justify-center w-full" },
                    React.createElement("span", { style: { color: color } }, isNonEmptyString(firstName) ? firstName.substring(0, 1).toUpperCase() : ''),
                    React.createElement("span", { style: { color: color } }, isNonEmptyString(lastName) ? lastName.substring(0, 1).toUpperCase() : '')))
            :
                React.createElement(SVG, { id: "page-header-me", style: __assign({ width: size }, svgStyle), color: color, src: notUser ? "/icons/my-location.svg" : "/icons/circle-user.svg" });
    };
    var renderAvatar = function () {
        return isNonEmptyString(data.avatar) && React.createElement("img", { className: "rounded-full border border-gray-20", src: data.avatar, alt: "", style: __assign({ width: size }, imgStyle) });
    };
    var renderUser = function () {
        return React.createElement(Menu, { as: "div", className: "relative inline-block text-left" },
            React.createElement(Menu.Button, { className: "flex text-sm", style: { minWidth: size, minHeight: size } },
                renderName(),
                renderAvatar()),
            isNonEmptyString(data === null || data === void 0 ? void 0 : data.currentStatus) && React.createElement("div", { className: "absolute right-0 top-0 rounded-full ".concat((data === null || data === void 0 ? void 0 : data.currentStatus) == 'on' ? 'bg-green-600' : 'bg-red-600'), style: { width: 10, height: 10 } }),
            isArray(menu) && menu.length > 0 && React.createElement(Transition, { as: Fragment, enter: "transition ease-out duration-100", enterFrom: "transform opacity-0 scale-95", enterTo: "transform opacity-100 scale-100", leave: "transition ease-in duration-75", leaveFrom: "transform opacity-100 scale-100", leaveTo: "transform opacity-0 scale-95" },
                React.createElement(Menu.Items, { className: "origin-top-right absolute z-50 right-0 mt-2 w-48 rounded-md shadow-lg bg-white ring-1 ring-black ring-opacity-5 focus:outline-none" },
                    React.createElement("div", { className: "py-1" }, map(menu, function (item, index) {
                        return React.createElement(Menu.Item, { key: "".concat(item.title, "-").concat(index) }, function (_a) {
                            var active = _a.active;
                            return (React.createElement("div", { onClick: item.onClick, className: "".concat(active ? 'bg-gray-100' : '', " cursor-pointer block px-4 py-2 text-base text-gray-700") }, item.title));
                        });
                    })))));
    };
    return hide ? null : React.createElement(React.Fragment, null,
        React.createElement("div", { className: "avatar ".concat(isNonEmptyString(wrapperClassName) ? wrapperClassName : ''), style: __assign({ width: size, height: size, position: 'relative' }, wrapperStyle) },
            renderUser(),
            isNumber(count) && count > 0 &&
                React.createElement("div", { className: "flex flex-row justify-center w-full", style: __assign(__assign({ width: size / 2, height: size / 2 }, styles.countWrapper), countWrapperStyle) },
                    React.createElement("div", { style: __assign(__assign({}, styles.count), countStyle) }, count > 9 ? '9+' : count))));
};
export default Avatar;
