//  Copyright PrimeObjects Software Inc. and other contributors <https://www.primeobjects.com/>
// 
//  This source code is licensed under the MIT license.
//  The detail information can be found in the LICENSE file in the root directory of this source tree.
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React, { Fragment } from 'react';
import SVG from '../svg';
import { Popover, Transition } from '@headlessui/react';
import { isArray, without, map, isNumber } from 'lodash';
import HeaderMenuActions from './menu-actions';
import HeaderMenuItems from './menu-items';
import HeaderMenuPosts from './menu-posts';
import { COLORS, isNonEmptyString } from 'primeobjects-helper-util';
export var HeaderMenuTitle = function (props) {
    var title = isNonEmptyString(props.title) ? props.title : 'Need Title';
    var colorName = isNonEmptyString(props.colorName) ? props.colorName : 'sky';
    var href = isNonEmptyString(props.href) ? props.href : '#';
    var maxWidth = isNumber(props.maxWidth) && props.maxWidth > 100 ? props.maxWidth : 400;
    var sections = isArray(props.sections) ? props.sections : [];
    var renderSections = function () {
        return without(map(sections, function (section, idx) {
            switch (section.type) {
                case 'items': return isArray(section.data) && React.createElement(HeaderMenuItems, { key: "".concat(idx), title: section.title, href: section.href, mobileView: section.mobileView, data: section.data, colorName: colorName });
                case 'actions': return isArray(section.data) && React.createElement(HeaderMenuActions, { key: "".concat(idx), title: section.title, data: section.data });
                case 'posts': return isArray(section.data) && React.createElement(HeaderMenuPosts, __assign({ key: idx }, section));
                default: return undefined;
            }
        }), undefined);
    };
    return !(isArray(sections) && sections.length > 0) ?
        React.createElement("a", { href: href, className: "text-base text-gray-600 hover:text-gray-900" },
            React.createElement("span", null, title)) :
        React.createElement(Popover, { className: "relative" }, function (_a) {
            var open = _a.open;
            return React.createElement(React.Fragment, null,
                React.createElement(Popover.Button, { className: [
                        'group bg-white rounded-md inline-flex items-center text-base focus:outline-none',
                        open ? "text-".concat(colorName, "-600 hover:text-").concat(colorName, "-500") : "text-gray-600 hover:text-gray-900",
                    ].join(' ') },
                    React.createElement("span", null, title),
                    React.createElement(SVG, { style: { width: 12, marginLeft: 10, marginTop: 2 }, src: "/icons/platform/chevron-down-menu.svg", color: open ? COLORS[colorName.toUpperCase()]['700'] : COLORS.GRAY['700'], className: open ? "flip-h" : "", "aria-hidden": "true" })),
                React.createElement(Transition, { as: Fragment, enter: "transition ease-out duration-200", enterFrom: "opacity-0 translate-y-1", enterTo: "opacity-100 translate-y-0", leave: "transition ease-in duration-150", leaveFrom: "opacity-100 translate-y-0", leaveTo: "opacity-0 translate-y-1" },
                    React.createElement(Popover.Panel, { className: "absolute -ml-4 mt-3 transform z-10 px-2 w-screen max-w-screen-xs sm:px-0 lg:ml-0 lg:left-1/2 lg:-translate-x-1/2", style: { maxWidth: maxWidth } },
                        React.createElement("div", { className: "rounded-lg shadow-lg ring-1 ring-black ring-opacity-5 overflow-hidden" }, renderSections()))));
        });
};
export default HeaderMenuTitle;
